@@ -21,6 +21,7 @@ pub struct UvInstallOptions {
     pub importlib_workaround: bool,
     pub extras: Vec<Requirement>,
     pub refresh: bool,
+    pub keyring_provider: KeyringProvider,
 }
 
 pub enum UvPackageUpgrade {
@@ -40,6 +41,7 @@ struct UvCompileOptions {
     pub no_header: bool,
     pub keyring_provider: KeyringProvider,
     pub generate_hashes: bool,
+    pub universal: bool,
 }
 
 impl UvCompileOptions {
@@ -64,6 +66,10 @@ impl UvCompileOptions {
             cmd.arg("--exclude-newer").arg(dt);
         }
 
+        if self.universal {
+            cmd.arg("--universal");
+        }
+
         match self.upgrade {
             UvPackageUpgrade::All => {
                 cmd.arg("--upgrade");
@@ -76,12 +82,7 @@ impl UvCompileOptions {
             UvPackageUpgrade::Nothing => {}
         }
 
-        match self.keyring_provider {
-            KeyringProvider::Disabled => {}
-            KeyringProvider::Subprocess => {
-                cmd.arg("--keyring-provider").arg("subprocess");
-            }
-        }
+        self.keyring_provider.add_as_pip_args(cmd);
     }
 }
 
@@ -95,10 +96,28 @@ impl Default for UvCompileOptions {
             no_header: false,
             generate_hashes: false,
             keyring_provider: KeyringProvider::Disabled,
+            universal: false,
         }
     }
 }
 
+pub struct UvSyncOptions {
+    pub keyring_provider: KeyringProvider,
+}
+
+impl UvSyncOptions {
+    pub fn add_as_pip_args(self, cmd: &mut Command) {
+        self.keyring_provider.add_as_pip_args(cmd);
+    }
+}
+
+impl Default for UvSyncOptions {
+    fn default() -> Self {
+        Self {
+            keyring_provider: KeyringProvider::Disabled,
+        }
+    }
+}
 pub struct UvBuilder {
     workdir: Option<PathBuf>,
     sources: Option<ExpandedSources>,
@@ -337,6 +356,7 @@ impl Uv {
         upgrade: UvPackageUpgrade,
         keyring_provider: KeyringProvider,
         generate_hashes: bool,
+        universal: bool,
     ) -> Result<(), Error> {
         let options = UvCompileOptions {
             allow_prerelease,
@@ -346,6 +366,7 @@ impl Uv {
             no_header: true,
             generate_hashes,
             keyring_provider,
+            universal,
         };
 
         let mut cmd = self.cmd();
@@ -502,6 +523,8 @@ impl UvWithVenv {
             cmd.arg("--refresh");
         }
 
+        options.keyring_provider.add_as_pip_args(&mut cmd);
+
         self.uv.sources.add_as_pip_args(&mut cmd);
 
         cmd.arg("--").arg(requirement.to_string());
@@ -537,10 +560,12 @@ impl UvWithVenv {
     }
 
     /// Syncs the venv
-    pub fn sync(&self, lockfile: &Path) -> Result<(), Error> {
+    pub fn sync(&self, lockfile: &Path, options: UvSyncOptions) -> Result<(), Error> {
         let mut cmd = self.venv_cmd();
         cmd.arg("pip").arg("sync");
 
+        options.add_as_pip_args(&mut cmd);
+
         self.uv.sources.add_as_pip_args(&mut cmd);
 
         let status = cmd
@@ -591,6 +616,7 @@ impl UvWithVenv {
             no_header: true,
             generate_hashes: false,
             keyring_provider,
+            universal: false,
         };
 
         cmd.arg("pip").arg("compile");
