@@ -30,7 +30,7 @@ fn test_init_lib() {
 
     ----- stderr -----
     Resolved 1 package in [EXECUTION_TIME]
-    Downloaded 1 package in [EXECUTION_TIME]
+    Prepared 1 package in [EXECUTION_TIME]
     Installed 1 package in [EXECUTION_TIME]
      + my-project==0.1.0 (from file:[TEMP_PATH]/project)
     "###);
@@ -79,7 +79,7 @@ fn test_init_default() {
 
     ----- stderr -----
     Resolved 1 package in [EXECUTION_TIME]
-    Downloaded 1 package in [EXECUTION_TIME]
+    Prepared 1 package in [EXECUTION_TIME]
     Installed 1 package in [EXECUTION_TIME]
      + my-project==0.1.0 (from file:[TEMP_PATH]/project)
     "###);
@@ -129,7 +129,7 @@ fn test_init_script() {
 
     ----- stderr -----
     Resolved 1 package in [EXECUTION_TIME]
-    Downloaded 1 package in [EXECUTION_TIME]
+    Prepared 1 package in [EXECUTION_TIME]
     Installed 1 package in [EXECUTION_TIME]
      + my-project==0.1.0 (from file:[TEMP_PATH]/project)
     "###);
